@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20241020';
+our $VERSION = '5.20250220';
 our %utilities;
 
 sub utilities {
@@ -2063,6 +2063,48 @@ my %delta = (
         removed => {
         }
     },
+    5.041006 => {
+        delta_from => 5.041005,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.041007 => {
+        delta_from => 5.041006,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.038003 => {
+        delta_from => 5.038002,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.040001 => {
+        delta_from => 5.040000,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.041008 => {
+        delta_from => 5.041007,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.041009 => {
+        delta_from => 5.041008,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
